# EasyDarts

Steel darts calibration and score recognition system


## Install

```
pip install easydarts
```

## Usage

1) Calibration


```
easydarts calibrate
```


2) Scorer

```
easydarts scorer
```
